==> amset-0.1.2.tar.gz: amset-0.1.2/docs/src/scattering.md <==
# Calculating scattering rates

AMSET calculates mode dependent scattering rates within the Born approximation 
using common materials parameters. The differential scattering rate from state 
$`\mathinner{|n\mathbf{k}\rangle}`$ to state 
$`\mathinner{|m\mathbf{k} + \mathbf{q}\rangle}`$ is calculated using 
Fermi's golden rule as

```math
    \tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1} = 
        \frac{2\pi}{\hbar} \lvert g_{nm}(\mathbf{k}, \mathbf{q}) \rvert^2
        \delta(\varepsilon_{n\mathbf{k}} - 
        \varepsilon_{m\mathbf{k}+\mathbf{q}}),
```

where $`\varepsilon_{n\mathbf{k}}`$ is the energy of state
$`\mathinner{|n\mathbf{k}\rangle}`$, and $`g_{nm}(\mathbf{k}, \mathbf{q})`$
is the matrix element for scattering from state 
$`\mathinner{|n\mathbf{k}\rangle}`$ into 
state $`\mathinner{|m\mathbf{k} + \mathbf{q}\rangle}`$. 

!!! info 
    Note, this is the expression for elastic scattering. Inelastic scattering
    contains addition terms, as detailed in the 
    [elastic vs inelastic scattering section](#elastic-vs-inelastic-scattering).

The overall mode-dependent scattering rate is obtained by 
[integrating the scattering rates](#brillouin-zone-integration) 
over the full Brillouin zone.  In this section, we report the matrix elements
for each scattering mechanism implemented in AMSET. Information on calculating 
transport properties is given in the 
[transport properties section](transport-properties.md).

## Summary of scattering rates

Mechanism                                                                               | Code  | Requires                                                                       | Type
---                                                                                     | ---   | ---                                                                            | ---
[Acoustic deformation potential scattering](#acoustic-deformation-potential-scattering) | ADP   | *n*- and *p*-type deformation potential,  elastic constant                     | Elastic
[Ionized impurity scattering](#ionized-impurity-scattering)                             | IMP   | static dielectric constant                                                     | Elastic
[Piezoelectric scattering](#piezoelectric-scattering)                                   | PIE   | static dielectric constant, piezoelectric coefficient                          | Elastic
[Polar optical phonon scattering](#polar-optical-phonon-scattering)                     | POP   | polar optical phonon frequency, static and high-frequency dielectric constants | Inelastic

### Acoustic deformation potential scattering

The acoustic deformation potential matrix element is given by

```math
g_{nm}(\mathbf{k}, \mathbf{q}) =
    \left [ \frac{k_\mathrm{B} T \varepsilon_\mathrm{d}^2}{C_\mathrm{el}} \right ] ^\frac{1}{2}
    \mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle},
```

where $`\varepsilon_\mathrm{d}`$ is the acoustic-phonon deformation-potential,
and $`C_\mathrm{el}`$ is the elastic constant.

!!! quote ""
    - *Abbreviation:* APD
    - *Type:* Elastic
    - *References:* [^Bardeen], [^Shockley], [^Rode]
    - *Requires:* `deformation_potential`, `elastic_constant`

### Ionized impurity scattering

The ionized impurity matrix element is given by

```math
g_{nm}(\mathbf{k}, \mathbf{q}) =
    \left [ \frac{e^2 n_\mathrm{ii}}{\epsilon_\mathrm{s}^2} \right ] ^\frac{1}{2}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right | ^2 + \beta^2},
```

where $`\epsilon_\mathrm{s}`$ is the static dielectric constant,
$`n_\mathrm{ii}`$ is the concentration of ionized impurities
(i.e., $`n_\mathrm{holes} + n_\mathrm{electrons}`$),
and $`\beta`$ is the inverse screening length, defined as

```math
    \beta^2 = \frac{e^2}{\epsilon_\mathrm{s}  k_\mathrm{B} T}
        \int \frac{\mathrm{d}\varepsilon}{V}\,D(\varepsilon) f(1-f),
```

where $`V`$ is the unit cell volume, $`D`$ is the density of states, and 
$`f`$ is the Fermi–Dirac distribution given in the
[transport properties section](transport-properties.md).

!!! quote ""
    - *Abbreviation:* IMP
    - *Type:* Elastic
    - *References:* [^Dingle], [^Rode]
    - *Requires:* `static_dielectric`

### Piezoelectric scattering

The piezoelectric differential scattering rate is given by

```math
g_{nm}(\mathbf{k}, \mathbf{q}) =
    \left [ \frac{k_\mathrm{B} T P_\mathrm{pie}^2}{\epsilon_\mathrm{s}} \right ] ^\frac{1}{2}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right |},
```

where $`P_\mathrm{pie}`$ is the dimensionless piezoelectric coefficient.

!!! quote ""
    - *Abbreviation:* PIE
    - *Type:* Elastic
    - *References:* [^Rode]
    - *Requires:* `piezoelectric_coefficient`, `static_dielectric`

### Polar optical phonon scattering

The polar optical phonon differential scattering rate is given by

```math
g_{nm}(\mathbf{k}, \mathbf{q}) =
    \left [ 
        \frac{\hbar \omega_\mathrm{po}}{2} 
        \left (\frac{1}{\epsilon_\infty} - \frac{1}{\epsilon_\mathrm{s}}\right)
    \right ] ^\frac{1}{2}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right |},
```

where $`\omega_\mathrm{po}`$ is the polar optical phonon frequency,
$`\epsilon_\infty`$ is the high-frequency dielectric constant.

!!! quote ""
    - *Abbreviation:* POP
    - *Type:* Inelastic
    - *References:* [^Frohlich], [^Conwell], [^Rode]
    - *Requires:* `pop_frequency`, `static_dielectric`, `high_frequency_dielectric`

## Elastic vs inelastic scattering

AMSET treats elastic and inelastic scattering mechanisms separately. 

### Inelastic

The  differential scattering rate for inelastic processes is calculated as

```math
\begin{aligned}
    \tau_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1} = 
        \frac{2\pi}{\hbar} \lvert g_{nm}(\mathbf{k}, \mathbf{q}) \rvert^2
        \times [ &{} (n_\mathrm{po} + 1 - f_{m\mathbf{k} + \mathbf{q}})
        \delta(\varepsilon_{n\mathbf{k}} -  \varepsilon_{m\mathbf{k}+\mathbf{q}} - \hbar\omega_\mathrm{po}) \\
        &{} (n_\mathrm{po} + f_{m\mathbf{k} + \mathbf{q}})
        \delta(\varepsilon_{n\mathbf{k}} -  \varepsilon_{m\mathbf{k}+\mathbf{q}} + \hbar\omega_\mathrm{po})],
\end{aligned}
```

where $`\omega_\mathrm{po}`$ is an effective phonon frequency, 
$`n_\mathrm{po} = 1 / [\exp (\hbar \omega_\mathrm{po} / k_\mathrm{B} T) - 1]`$
denotes the Bose–Einstein distribution of phonons, and the
$`-\hbar \omega_\mathrm{po}`$ and 
$`+\hbar \omega_\mathrm{po}`$ terms correspond to scattering by phonon 
absorption and emission, respectively.

The overall inelastic scattering rate for state 
$`\mathinner{|n\mathbf{k}\rangle}`$ is calculated as

```math
\tau^{-1}_{n\mathbf{k}} = \sum_m \int \frac{\mathrm{d}^3q}{\Omega} 
\tau_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}
```

where $`\Omega`$ is the volume of the Brillouin zone.

### Elastic

Elastic rates are calculated using the *momentum relaxation time approximation*
(MRTA), given by

```math
\tilde{\tau}^{-1}_{n\mathbf{k}} = \sum_m \int \frac{\mathrm{d}^3q}{\Omega} 
    \left [ 1 - \frac{\mathbf{v}_{n\mathbf{k}} \cdot \mathbf{v}_{m\mathbf{k} + 
        \mathbf{q}}}{\lvert \mathbf{v}_{n\mathbf{k}} \rvert^2} \right ]

    \tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}
```
where $`\tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}`$ is
the elastic differential scattering rate defined at the top of this page and 
$`\mathbf{v}_{n\mathbf{k}}`$ is the group velocity of state 
$`\mathinner{|n\mathbf{k}\rangle}`$.

## Overlap integral

In the Born approximation, the scattering rate equations depend on the 
wavefunction overlap 
$`\mathinner{\langle{\psi_{m\mathbf{k}^\prime}|\psi_{n\mathbf{k}}}\rangle}`$.
AMSET uses [pawpyseed](https://pypi.org/project/pawpyseed/) to obtain
wavefunction coefficients including PAW core regions from the pseudo wavefunction
coefficients written by VASP.
The wavefunctions coefficient are linearly interpolated onto the mesh used to
calculate scattering rates.

## Brillouin zone integration

All scattering rates depend on the Dirac delta function $`\delta`$,
which imposes conservation of energy. Due to finite k-point sampling and 
numerical noise, it is unlikely that this condition will ever be satisfied 
exactly. Furthermore, many scattering rates have a 
$`1 / \lvert\mathbf{q}\rvert ^2`$ dependence which
requires an extremely dense k-point mesh to achieve convergence.

To account for this, AMSET employs a modified tetrahedron integration
scheme. AMSET first identifies a constant energy surface by computing
tetrahedral cross sections using the tetrahedron method. Next, the constant 
energy surface is resampled using an ultra-fine mesh of k-points generated using
the [quadpy](https://github.com/nschloe/quadpy) numerical integration package.
The wavefunction coefficients and group velocities are reinterpolated into the 
ultra-fine mesh using linear interpolation and the matrix elements are 
calculated directly. This methodology allows for significantly faster 
convergence than the regular tetrahedron method.

The methodology for combining rates from multiple scattering mechanisms is given
in the [transport properties section](transport-properties.md).

[^Rode]: Rode, D. L. *Low-field electron transport. Semiconductors and semimetals* **10**, (Elsevier, 1975).

[^Shockley]: Shockley, W. & others. *Electrons and holes in semiconductors: with applications to transistor electronics.* (van Nostrand New York, 1950).

[^Bardeen]: Bardeen, J. & Shockley, W. *Deformation potentials and mobilities in non-polar crystals.* Phys. Rev. **80**, 72-80 (1950).

[^Dingle]: Dingle, R. B. *XCIV. Scattering of electrons and holes by charged donors and acceptors in semiconductors.* London, Edinburgh, Dublin Philos. Mag. J. Sci. **46**, 831-840 (1955).

[^Frohlich]: Fröhlich, H. *Electrons in lattice fields.* Adv. Phys. **3**, 325–361 (1954).

[^Conwell]: Conwell, E. M. *High Field Transport in Semiconductors.* Academic Press, New York (1967).

==> amset-0.1.3.tar.gz: amset-0.1.3/docs/src/scattering.md <==
# Calculating scattering rates

AMSET calculates mode dependent scattering rates within the Born approximation 
using common materials parameters. The differential scattering rate from state 
$`\mathinner{|n\mathbf{k}\rangle}`$ to state 
$`\mathinner{|m\mathbf{k} + \mathbf{q}\rangle}`$ is calculated using 
Fermi's golden rule as

```math
    \tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1} = 
        \frac{2\pi}{\hbar} \lvert g_{nm}(\mathbf{k}, \mathbf{q}) \rvert^2
        \delta(\varepsilon_{n\mathbf{k}} - 
        \varepsilon_{m\mathbf{k}+\mathbf{q}}),
```

where $`\varepsilon_{n\mathbf{k}}`$ is the energy of state
$`\mathinner{|n\mathbf{k}\rangle}`$, and $`g_{nm}(\mathbf{k}, \mathbf{q})`$
is the matrix element for scattering from state 
$`\mathinner{|n\mathbf{k}\rangle}`$ into 
state $`\mathinner{|m\mathbf{k} + \mathbf{q}\rangle}`$. 

!!! info 
    Note, this is the expression for elastic scattering. Inelastic scattering
    contains addition terms, as detailed in the 
    [elastic vs inelastic scattering section](#elastic-vs-inelastic-scattering).

The overall mode-dependent scattering rate is obtained by 
[integrating the scattering rates](#brillouin-zone-integration) 
over the full Brillouin zone.  In this section, we report the matrix elements
for each scattering mechanism implemented in AMSET. Information on calculating 
transport properties is given in the 
[transport properties section](transport-properties.md).

## Summary of scattering rates

Mechanism                                                                               | Code  | Requires                                                                       | Type
---                                                                                     | ---   | ---                                                                            | ---
[Acoustic deformation potential scattering](#acoustic-deformation-potential-scattering) | ADP   | *n*- and *p*-type deformation potential,  elastic constant                     | Elastic
[Ionized impurity scattering](#ionized-impurity-scattering)                             | IMP   | static dielectric constant                                                     | Elastic
[Piezoelectric scattering](#piezoelectric-scattering)                                   | PIE   | static dielectric constant, piezoelectric coefficient                          | Elastic
[Polar optical phonon scattering](#polar-optical-phonon-scattering)                     | POP   | polar optical phonon frequency, static and high-frequency dielectric constants | Inelastic

### Acoustic deformation potential scattering

The acoustic deformation potential matrix element is given by
```math
g_{nm}^\mathrm{ad}(\mathbf{k}, \mathbf{q}) =
    \sqrt{k_\mathrm{B} T}
    \left[ 
        \frac{(\mathbf{D}_{n\mathbf{k}} : \mathbf{\hat{q}} \otimes \mathbf{\hat{q}})^2}
             {\mathbf{Q}_\mathbf{q}\mathbf{\hat{q}}\cdot\mathbf{\hat{q}}} + 
        \frac{(\mathbf{D}_{n\mathbf{k}} : \mathbf{\hat{q}} \otimes \mathbf{\hat{q}}_{t_1})^2}
             {\mathbf{Q}_\mathbf{q}\mathbf{\hat{q}}_{t_1}\cdot\mathbf{\hat{q}}_{t_1}} +
        \frac{(\mathbf{D}_{n\mathbf{k}} : \mathbf{\hat{q}} \otimes \mathbf{\hat{q}}_{t_2})^2}
             {\mathbf{Q}_\mathbf{q}\mathbf{\hat{q}}_{t_2}\cdot\mathbf{\hat{q}}_{t_2}}
    \right]^\frac{1}{2}
    \mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle},
```
where $`\mathbf{D}_{n\mathbf{k}}`$ is the rank 2 volume deformation potential 
tensor for state $`\mathinner{|n\mathbf{k}\rangle}`$, 
$`\mathbf{Q}_\mathbf{q} = \mathbf{\hat{q}} \cdot \mathbf{C} \cdot \mathbf{\hat{q}}`$ 
is the acoustic tensor in the direction of $`\mathbf{q}`$, $`\mathbf{C}`$ is the 
rank 4 elastic constant tensor, and 
$`\mathbf{\hat{q}} = \mathbf{q} / |\mathbf{q}|`$ is the unit scattering direction.
The vectors $`\mathbf{\hat{q}}_{t_1}`$ and $`\mathbf{\hat{q}}_{t_2}`$ are unit 
vectors perpendicular to $`\mathbf{\hat{q}}`$ and to each other, such that the 
three form an orthogonal basis.
The first term given in square brackets accounts for scattering due to 
longitudinal phonons, whereas the second two terms describe scattering from 
transverse modes.

!!! quote ""
    - *Abbreviation:* APD
    - *Type:* Elastic
    - *References:* [^Bardeen], [^Shockley], [^Rode]
    - *Requires:* `deformation_potential`, `elastic_constant`

### Ionized impurity scattering

The ionized impurity matrix element is given by
```math
g_{nm}^\mathrm{ii}(\mathbf{k}, \mathbf{q}) =
     \frac{n_\mathrm{ii}^{1/2} Z e }{\mathbf{\hat{q}} \cdot \boldsymbol{\epsilon}_\mathrm{s} \cdot \mathbf{\hat{q}}}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right | ^2 + \beta^2},
```
where $`\boldsymbol{\epsilon}_\mathrm{s}`$ is the static dielectric constant,
$`n_\mathrm{ii}`$ is the concentration of ionized impurities
(i.e., $`n_\mathrm{holes} + n_\mathrm{electrons}`$),
and $`\beta`$ is the inverse screening length, defined as

```math
    \beta^2 = \frac{e^2}{\epsilon_\mathrm{s}  k_\mathrm{B} T}
        \int \frac{\mathrm{d}\varepsilon}{V}\,D(\varepsilon) f(1-f),
```

where $`V`$ is the unit cell volume, $`D`$ is the density of states, and 
$`f`$ is the Fermi–Dirac distribution given in the
[transport properties section](transport-properties.md).

!!! quote ""
    - *Abbreviation:* IMP
    - *Type:* Elastic
    - *References:* [^Dingle], [^Rode]
    - *Requires:* `static_dielectric`

### Piezoelectric scattering

The piezoelectric differential scattering rate is given by

```math
g_{nm}^\mathrm{pi}(\mathbf{k}, \mathbf{q}) =
    \left [ \frac{k_\mathrm{B} T d^2}{\mathbf{\hat{q}}\cdot\boldsymbol{\epsilon}_\mathrm{s}\cdot\mathbf{\hat{q}}} \right ] ^\frac{1}{2}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right |},
```

where $`d`$ is the dimensionless piezoelectric coefficient.

!!! quote ""
    - *Abbreviation:* PIE
    - *Type:* Elastic
    - *References:* [^Rode]
    - *Requires:* `piezoelectric_coefficient`, `static_dielectric`

### Polar optical phonon scattering

The polar optical phonon differential scattering rate is given by

```math
g_{nm}^\mathrm{po}(\mathbf{k}, \mathbf{q}) = 
    \left [ 
        \frac{\hbar \omega_\mathrm{po}}{2} 
        \left (\frac{1}{\mathbf{\hat{q}}\cdot\boldsymbol{\epsilon}_\infty\cdot\mathbf{\hat{q}}} - \frac{1}{\mathbf{\hat{q}}\cdot\boldsymbol{\epsilon}_\mathrm{s}\cdot\mathbf{\hat{q}}}\right)
    \right ] ^\frac{1}{2}
    \frac{\mathinner{\langle{\psi_{m\mathbf{k}+\mathbf{q}}|\psi_{n\mathbf{k}}}\rangle}}
         {\left | \mathbf{q} \right |},
```

where $`\omega_\mathrm{po}`$ is the polar optical phonon frequency,
and $`\boldsymbol{\epsilon}_\infty`$ is the high-frequency dielectric constant tensor.

!!! quote ""
    - *Abbreviation:* POP
    - *Type:* Inelastic
    - *References:* [^Frohlich], [^Conwell], [^Rode]
    - *Requires:* `pop_frequency`, `static_dielectric`, `high_frequency_dielectric`

## Elastic vs inelastic scattering

AMSET treats elastic and inelastic scattering mechanisms separately. 

### Inelastic

The  differential scattering rate for inelastic processes is calculated as

```math
\begin{aligned}
    \tau_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1} = 
        \frac{2\pi}{\hbar} \lvert g_{nm}(\mathbf{k}, \mathbf{q}) \rvert^2
        \times [ &{} (n_\mathrm{po} + 1 - f_{m\mathbf{k} + \mathbf{q}})
        \delta(\varepsilon_{n\mathbf{k}} -  \varepsilon_{m\mathbf{k}+\mathbf{q}} - \hbar\omega_\mathrm{po}) \\
        &{} (n_\mathrm{po} + f_{m\mathbf{k} + \mathbf{q}})
        \delta(\varepsilon_{n\mathbf{k}} -  \varepsilon_{m\mathbf{k}+\mathbf{q}} + \hbar\omega_\mathrm{po})],
\end{aligned}
```

where $`\omega_\mathrm{po}`$ is an effective phonon frequency, 
$`n_\mathrm{po} = 1 / [\exp (\hbar \omega_\mathrm{po} / k_\mathrm{B} T) - 1]`$
denotes the Bose–Einstein distribution of phonons, and the
$`-\hbar \omega_\mathrm{po}`$ and 
$`+\hbar \omega_\mathrm{po}`$ terms correspond to scattering by phonon 
absorption and emission, respectively.

The overall inelastic scattering rate for state 
$`\mathinner{|n\mathbf{k}\rangle}`$ is calculated as

```math
\tau^{-1}_{n\mathbf{k}} = \sum_m \int \frac{\mathrm{d}^3q}{\Omega} 
\tau_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}
```

where $`\Omega`$ is the volume of the Brillouin zone.

### Elastic

Elastic rates are calculated using the *momentum relaxation time approximation*
(MRTA), given by

```math
\tilde{\tau}^{-1}_{n\mathbf{k}} = \sum_m \int \frac{\mathrm{d}^3q}{\Omega} 
    \left [ 1 - \frac{\mathbf{v}_{n\mathbf{k}} \cdot \mathbf{v}_{m\mathbf{k} + 
        \mathbf{q}}}{\lvert \mathbf{v}_{n\mathbf{k}} \rvert^2} \right ]

    \tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}
```
where $`\tilde{\tau}_{n\mathbf{k}\rightarrow m\mathbf{k}+\mathbf{q}}^{-1}`$ is
the elastic differential scattering rate defined at the top of this page and 
$`\mathbf{v}_{n\mathbf{k}}`$ is the group velocity of state 
$`\mathinner{|n\mathbf{k}\rangle}`$.

## Overlap integral

In the Born approximation, the scattering rate equations depend on the 
wavefunction overlap 
$`\mathinner{\langle{\psi_{m\mathbf{k}^\prime}|\psi_{n\mathbf{k}}}\rangle}`$.
AMSET uses [pawpyseed](https://pypi.org/project/pawpyseed/) to obtain
wavefunction coefficients including PAW core regions from the pseudo wavefunction
coefficients written by VASP.
The wavefunctions coefficient are linearly interpolated onto the mesh used to
calculate scattering rates.

## Brillouin zone integration

All scattering rates depend on the Dirac delta function $`\delta`$,
which imposes conservation of energy. Due to finite k-point sampling and 
numerical noise, it is unlikely that this condition will ever be satisfied 
exactly. Furthermore, many scattering rates have a 
$`1 / \lvert\mathbf{q}\rvert ^2`$ dependence which
requires an extremely dense k-point mesh to achieve convergence.

To account for this, AMSET employs a modified tetrahedron integration
scheme. AMSET first identifies a constant energy surface by computing
tetrahedral cross sections using the tetrahedron method. Next, the constant 
energy surface is resampled using an ultra-fine mesh of k-points generated using
the [quadpy](https://github.com/nschloe/quadpy) numerical integration package.
The wavefunction coefficients and group velocities are reinterpolated into the 
ultra-fine mesh using linear interpolation and the matrix elements are 
calculated directly. This methodology allows for significantly faster 
convergence than the regular tetrahedron method.

The methodology for combining rates from multiple scattering mechanisms is given
in the [transport properties section](transport-properties.md).

[^Rode]: Rode, D. L. *Low-field electron transport. Semiconductors and semimetals* **10**, (Elsevier, 1975).

[^Shockley]: Shockley, W. & others. *Electrons and holes in semiconductors: with applications to transistor electronics.* (van Nostrand New York, 1950).

[^Bardeen]: Bardeen, J. & Shockley, W. *Deformation potentials and mobilities in non-polar crystals.* Phys. Rev. **80**, 72-80 (1950).

[^Dingle]: Dingle, R. B. *XCIV. Scattering of electrons and holes by charged donors and acceptors in semiconductors.* London, Edinburgh, Dublin Philos. Mag. J. Sci. **46**, 831-840 (1955).

[^Frohlich]: Fröhlich, H. *Electrons in lattice fields.* Adv. Phys. **3**, 325–361 (1954).

[^Conwell]: Conwell, E. M. *High Field Transport in Semiconductors.* Academic Press, New York (1967).
